==> activity-center-api-1.5.3.xxd5-20170424.113357-1-sources.jar: cn/com/duiba/activity/center/api/dto/sign/system/SignActivityDto.java <==
package cn.com.duiba.activity.center.api.dto.sign.system;

import cn.com.duiba.activity.center.api.enums.SignActivityStatusEnum;
import cn.com.duiba.activity.center.api.enums.SignActivityTypeEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaoxuda on 2017/4/20.
 */
public class SignActivityDto implements Serializable{
    private static final long serialVersionUID = 1752779918200677322L;

    public static final Integer AppDirectSwitch = 1;
    public static final Integer DeveloperBlackSwitch = 2;

    private Long id;
    /**
     * 签到活动标题
     */
    private String title;

    /**
     * 签到活动类型
     */
    private SignActivityTypeEnum signType;

    /**
     * 描述
     */
    private String description;

    /**
     * 活动状态
     */
    private SignActivityStatusEnum status;
    /**
     * 功能开关，位运算保存
     */
    private Integer switches;
    /**
     * 预览图
     */
    private String previewImage;
    /**
     * 删除状态
     */
    private Boolean deleted;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public SignActivityTypeEnum getSignType() {
        return signType;
    }

    public void setSignType(SignActivityTypeEnum signType) {
        this.signType = signType;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public SignActivityStatusEnum getStatus() {
        return status;
    }

    public void setStatus(SignActivityStatusEnum status) {
        this.status = status;
    }

    public Integer getSwitches() {
        return switches;
    }

    public void setSwitches(Integer switches) {
        this.switches = switches;
    }

    public String getPreviewImage() {
        return previewImage;
    }

    public void setPreviewImage(String previewImage) {
        this.previewImage = previewImage;
    }

    public Boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> activity-center-api-1.6.8.xxd-20170605.025956-1-sources.jar: cn/com/duiba/activity/center/api/dto/sign/system/SignActivityDto.java <==
package cn.com.duiba.activity.center.api.dto.sign.system;

import cn.com.duiba.activity.center.api.enums.SignActivityStatusEnum;
import cn.com.duiba.activity.center.api.enums.SignActivityTypeEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaoxuda on 2017/4/20.
 */
public class SignActivityDto implements Serializable{
    private static final long serialVersionUID = 1752779918200677322L;

    public static final Integer AppDirectSwitch = 1;
    public static final Integer DeveloperBlackSwitch = 2;

    private Long id;
    /**
     * 签到活动标题
     */
    private String title;

    /**
     * 签到活动类型
     */
    private SignActivityTypeEnum signType;

    /**
     * 描述
     */
    private String description;

    /**
     * 活动状态
     */
    private SignActivityStatusEnum status;
    /**
     * 功能开关，位运算保存
     */
    private Integer switches;
    /**
     * 预览图
     */
    private String previewImage;
    /**
     * 删除状态
     */
    private Boolean deleted;

    /**
     * 额外字段
     */
    private String extra;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public SignActivityTypeEnum getSignType() {
        return signType;
    }

    public void setSignType(SignActivityTypeEnum signType) {
        this.signType = signType;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public SignActivityStatusEnum getStatus() {
        return status;
    }

    public void setStatus(SignActivityStatusEnum status) {
        this.status = status;
    }

    public Integer getSwitches() {
        return switches;
    }

    public void setSwitches(Integer switches) {
        this.switches = switches;
    }

    public String getPreviewImage() {
        return previewImage;
    }

    public void setPreviewImage(String previewImage) {
        this.previewImage = previewImage;
    }

    public Boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }
}
